@@ -33,6 +33,8 @@
 #'
 #' @references James, G., Witten, D., Hastie, T., & Tibshirani, R. (Hrsg.). (2013). An introduction to statistical learning: with applications in R. New York: Springer.
 #'
+#' @note There is also a \href{https://easystats.github.io/see/articles/performance.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#'
 #' @examples
 #' m <- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
 #' check_collinearity(m)
@@ -245,7 +247,7 @@ check_collinearity.zerocount <- function(x, component = c("all", "conditional",
 #' @importFrom insight get_data find_predictors find_parameters clean_names
 .find_term_assignment <- function(x, component) {
   pred <- insight::find_predictors(x)[[component]]
-  dat <- insight::get_data(x)[, pred]
+  dat <- insight::get_data(x)[, pred, drop = FALSE]
 
   parms <- unlist(lapply(1:length(pred), function(i) {
     p <- pred[i]
