@@ -16,6 +16,8 @@
 #' information on the distance measure and whether or not an observation is considered
 #' as outlier.
 #'
+#' @note There is also a \href{https://easystats.github.io/see/articles/performance.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#'
 #' @details Outliers can be defined as particularly influential observations. Most methods rely on the computation of some distance metric, and the observations greater than a certain threshold are considered outliers. Importantly, outliers detection methods are meant to provide information to the researcher, rather than being an automatized procedure which mindless application is a substitute for thinking.
 #'
 #' An \strong{example sentence} for reporting the usage of the composite method could be:
@@ -32,7 +34,7 @@
 #'  distribution with p and n-p degrees of freedom, the median point of the quantile
 #'  distribution can be used as a cut-off (Bollen, 1985). A common approximation
 #'  or heuristic is to use 4 divided by the numbers of observations, which usually
-#'  correponds to a lower threshold (i.e., more outliers are detected). This only works for Frequentist models. For Bayesian models, see \code{pareto}.
+#'  corresponds to a lower threshold (i.e., more outliers are detected). This only works for Frequentist models. For Bayesian models, see \code{pareto}.
 #'
 #' \item \strong{Pareto}:
 #' The reliability and approximate convergence of Bayesian models can be assessed using the estimates for the shape parameter k of the generalized Pareto distribution. If the estimated tail shape parameter k exceeds 0.5, the user should be warned, although in practice the authors of the \code{loo} package observed good performance for values of k up to 0.7 (the default threshold used by \code{performance}).
@@ -84,7 +86,7 @@
 #'  to be installed, and that it takes some time to compute the results.
 #'
 #' \item \strong{OPTICS}:
-#'  The Ordering Points To Identify the Clustering Structure (OPTICS) algorithm (Ankerst et al., 1999) is using similar concepts to DBSCAN (an unsupervised clustering technique that can be used for outliers detection). The threshold argument is passsed as \code{minPts}, which corresponds to the minimum size of a cluster. By default, this size is set at 2 times the number of columns (Sander et al., 1998). Compared to the others techniques, that will always detect several outliers (as these are usually defined as a percentage of extreme values), this algorithm functions in a different manner and won't always detect outliers. Note that \code{method = "optics"} requires the \pkg{dbscan} package to be installed, and that it takes some time to compute the results.
+#'  The Ordering Points To Identify the Clustering Structure (OPTICS) algorithm (Ankerst et al., 1999) is using similar concepts to DBSCAN (an unsupervised clustering technique that can be used for outliers detection). The threshold argument is passed as \code{minPts}, which corresponds to the minimum size of a cluster. By default, this size is set at 2 times the number of columns (Sander et al., 1998). Compared to the others techniques, that will always detect several outliers (as these are usually defined as a percentage of extreme values), this algorithm functions in a different manner and won't always detect outliers. Note that \code{method = "optics"} requires the \pkg{dbscan} package to be installed, and that it takes some time to compute the results.
 #'
 #' \item \strong{Isolation Forest}:
 #'  The outliers are detected using the anomaly score of an isolation forest (a class of random forest). The default threshold
@@ -204,7 +206,7 @@ check_outliers.default <- function(x, method = c("cook", "pareto"), threshold =
   }
 
   # Cook
-  if ("cook" %in% c(method) & insight::model_info(x)$is_bayesian == FALSE) {
+  if ("cook" %in% c(method) & insight::model_info(x)$is_bayesian == FALSE & !inherits(x, "bife")) {
     df <- cbind(df, .check_outliers_cook(x, threshold = thresholds$cook)$data_cook)
   }
   # Pareto
@@ -243,10 +245,6 @@ check_outliers.numeric <- function(x, method = "zscore", threshold = NULL, ...)
 
 
 
-
-
-
-
 #' @rdname check_outliers
 #' @export
 check_outliers.data.frame <- function(x, method = "mahalanobis", threshold = NULL, ...) {
@@ -354,20 +352,24 @@ as.numeric.check_outliers <- function(x, ...) {
 
 
 
+.check_outliers_thresholds <- function(x) {
+  suppressWarnings(.check_outliers_thresholds_nowarn(x))
+}
+
 #' @importFrom stats qf qchisq
-.check_outliers_thresholds <- function(x,
-                                       zscore = stats::qnorm(p = 1 - 0.025),
-                                       iqr = 1.5,
-                                       cook = stats::qf(0.5, ncol(x), nrow(x) - ncol(x)),
-                                       pareto = 0.7,
-                                       mahalanobis = stats::qchisq(p = 1 - 0.025, df = ncol(x)),
-                                       robust = stats::qchisq(p = 1 - 0.025, df = ncol(x)),
-                                       mcd = stats::qchisq(p = 1 - 0.025, df = ncol(x)),
-                                       ics = 0.025,
-                                       optics = 2 * ncol(x),
-                                       iforest = 0.025,
-                                       lof = 0.025,
-                                       ...) {
+.check_outliers_thresholds_nowarn <- function(x) {
+  zscore <- stats::qnorm(p = 1 - 0.025)
+  iqr <- 1.5
+  cook <- stats::qf(0.5, ncol(x), nrow(x) - ncol(x))
+  pareto <- 0.7
+  mahalanobis <- stats::qchisq(p = 1 - 0.025, df = ncol(x))
+  robust <- stats::qchisq(p = 1 - 0.025, df = ncol(x))
+  mcd <- stats::qchisq(p = 1 - 0.025, df = ncol(x))
+  ics <- 0.025
+  optics <- 2 * ncol(x)
+  iforest <- 0.025
+  lof <- 0.025
+
   list(
     "zscore" = zscore,
     "iqr" = iqr,
@@ -385,12 +387,13 @@ as.numeric.check_outliers <- function(x, ...) {
 
 
 
+#' @importFrom stats median sd qnorm mad
 .check_outliers_zscore <- function(x, threshold = stats::qnorm(p = 1 - 0.025), robust = TRUE, method = "max") {
   # Standardize
   if (robust == FALSE) {
-    d <- abs(as.data.frame(sapply(x, function(x) (x - mean(x, na.rm = TRUE)) / sd(x, na.rm = TRUE))))
+    d <- abs(as.data.frame(sapply(x, function(x) (x - mean(x, na.rm = TRUE)) / stats::sd(x, na.rm = TRUE))))
   } else {
-    d <- abs(as.data.frame(sapply(x, function(x) (x - median(x, na.rm = TRUE)) / mad(x, na.rm = TRUE))))
+    d <- abs(as.data.frame(sapply(x, function(x) (x - stats::median(x, na.rm = TRUE)) / stats::mad(x, na.rm = TRUE))))
   }
 
   out <- data.frame(Obs = 1:nrow(as.data.frame(d)))
@@ -647,7 +650,7 @@ as.numeric.check_outliers <- function(x, ...) {
 
 
 #' @importFrom utils packageVersion
-#' @importFrom stats median qnorm mad sd
+#' @importFrom stats median qnorm mad sd predict
 .check_outliers_iforest <- function(x, threshold = 0.025) {
   out <- data.frame(Obs = 1:nrow(x))
 
@@ -659,10 +662,10 @@ as.numeric.check_outliers <- function(x, ...) {
   # Compute
   if (utils::packageVersion("solitude") < "0.2.0") {
     iforest <- solitude::isolationForest(x)
-    out$Distance_iforest <- predict(iforest, x, type = "anomaly_score")
-  } else if (utils::packageVersion("solitude") == "0.2.0"){
+    out$Distance_iforest <- stats::predict(iforest, x, type = "anomaly_score")
+  } else if (utils::packageVersion("solitude") == "0.2.0") {
     stop("Must update package `solitude` (above version 0.2.0). Please run `install.packages('solitude')`.", call. = FALSE)
-  } else{
+  } else {
     iforest <- solitude::isolationForest$new(sample_size = nrow(x))
     suppressMessages(iforest$fit(x))
     out$Distance_iforest <- iforest$scores$anomaly_score
@@ -711,7 +714,28 @@ as.numeric.check_outliers <- function(x, ...) {
 
 
 
+
+
+
+
+# Non-supported model classes ---------------------------------------
+
 #' @export
 check_outliers.glmmTMB <- function(x, ...) {
   NULL
 }
+
+#' @export
+check_outliers.lme <- function(x, ...) {
+  NULL
+}
+
+#' @export
+check_outliers.lmrob <- function(x, ...) {
+  NULL
+}
+
+#' @export
+check_outliers.glmrob <- function(x, ...) {
+  NULL
+}
