@@ -72,7 +72,7 @@ model_performance.stanreg <- function(model, metrics = "all", verbose = TRUE, ..
     out$WAIC <- suppressWarnings(loo::waic(model)$estimates["waic", "Estimate"])
   }
   if ("R2" %in% c(metrics)) {
-    r2 <- r2_bayes(model, ...)
+    r2 <- r2_bayes(model)
     attri$r2_bayes <- attributes(r2) # save attributes
 
     # Format to df then to list
@@ -83,7 +83,7 @@ model_performance.stanreg <- function(model, metrics = "all", verbose = TRUE, ..
   if ("R2_adjusted" %in% c(metrics) && mi$is_linear) {
     out$R2_adjusted <- suppressWarnings(r2_loo(model))
   }
-  if ("RMSE" %in% c(metrics) && !mi$is_ordinal && !mi$is_categorical) {
+  if ("RMSE" %in% c(metrics) && !mi$is_ordinal && !mi$is_multinomial && !mi$is_categorical) {
     out$RMSE <- performance_rmse(model, verbose = verbose)
   }
   if (("LOGLOSS" %in% metrics) && mi$is_binomial) {
