@@ -5,7 +5,6 @@
 #'   from a model with binary or count outcome.
 #'
 #' @param model Model with binary or count outcome.
-#' @param ... Currently not used.
 #' @inheritParams model_performance.lm
 #'
 #' @return A list with three elements, the logarithmic, quadratic/Brier and spherical score.
@@ -46,7 +45,7 @@
 #'     data = Salamanders
 #'   )
 #'
-#' performance_score(model)
+#'   performance_score(model)
 #' }
 #' }
 #'
@@ -56,8 +55,8 @@
 performance_score <- function(model, verbose = TRUE) {
   minfo <- insight::model_info(model)
 
-  if (minfo$is_ordinal) {
-    if (verbose) insight::print_color("Can't calculate proper scoring rules for ordinal or cumulative link models.\n", "red")
+  if (minfo$is_ordinal || minfo$is_multinomial) {
+    if (verbose) insight::print_color("Can't calculate proper scoring rules for ordinal, multinomial or cumulative link models.\n", "red")
     return(list(logarithmic = NA, quadratic = NA, spherical = NA))
   }
 
