@@ -5,7 +5,7 @@
 #'   on the model, R2, pseudo-R2 or marginal / adjusted R2 values are returned.
 #'
 #' @param model A statistical model.
-#' @param ... Currently not used.
+#' @param ... Arguments passed down to the related r2-methods.
 #'
 #' @return Returns a list containing values related to the most appropriate R2
 #'   for the given model. See the list below:
@@ -152,6 +152,9 @@ r2.BBreg <- function(model, ...) {
 #' @export
 r2.crch <- r2.BBreg
 
+#' @export
+r2.bayesx <- r2.BBreg
+
 
 
 
@@ -233,7 +236,7 @@ r2.zeroinfl <- r2.hurdle
 
 #' @export
 r2.merMod <- function(model, ...) {
-  r2_nakagawa(model)
+  r2_nakagawa(model, ...)
 }
 
 #' @export
@@ -311,6 +314,19 @@ r2.stanreg <- r2.brmsfit
 # Other methods ------------------------------
 
 
+#' @export
+r2.gam <- function(model, ...) {
+  s <- summary(model)
+  if (!is.null(s$r.sq)) {
+    list(
+      R2 = c(`Adjusted R2` = s$r.sq)
+    )
+  } else {
+    NextMethod()
+  }
+}
+
+
 #' @export
 r2.betareg <- function(model, ...) {
   list(
