@@ -51,7 +51,11 @@ r2_nagelkerke <- function(model) {
 
 #' @export
 r2_nagelkerke.glm <- function(model) {
-  r2_nagelkerke <- r2_coxsnell(model) / (1 - exp(-model$null.deviance / insight::n_obs(model)))
+  r2cox <- r2_coxsnell(model)
+  if (is.na(r2cox) || is.null(r2cox)) {
+    return(NULL)
+  }
+  r2_nagelkerke <- r2cox / (1 - exp(-model$null.deviance / insight::n_obs(model)))
   names(r2_nagelkerke) <- "Nagelkerke's R2"
   r2_nagelkerke
 }
@@ -59,6 +63,13 @@ r2_nagelkerke.glm <- function(model) {
 #' @export
 r2_nagelkerke.BBreg <- r2_nagelkerke.glm
 
+#' @export
+r2_nagelkerke.bife <- function(model) {
+  r2_nagelkerke <- r2_coxsnell(model) / (1 - exp(-model$null_deviance / insight::n_obs(model)))
+  names(r2_nagelkerke) <- "Nagelkerke's R2"
+  r2_nagelkerke
+}
+
 
 
 
@@ -83,6 +94,10 @@ r2_nagelkerke.clm2 <- function(model) {
 #' @export
 r2_nagelkerke.clm <- function(model) {
   l_base <- stats::logLik(stats::update(model, ~1))
+  # if no loglik, return NA
+  if (length(as.numeric(l_base)) == 0) {
+    return(NULL)
+  }
   .r2_nagelkerke(model, l_base)
 }
 
@@ -110,6 +125,9 @@ r2_nagelkerke.censReg <- r2_nagelkerke.clm
 #' @export
 r2_nagelkerke.truncreg <- r2_nagelkerke.clm
 
+#' @export
+r2_nagelkerke.DirichletRegModel <- r2_coxsnell.clm
+
 
 
 
@@ -129,3 +147,9 @@ r2_nagelkerke.survreg <- r2_nagelkerke.coxph
 
 #' @export
 r2_nagelkerke.crch <- r2_nagelkerke.coxph
+
+#' @export
+r2_nagelkerke.svycoxph <- function(model) {
+  l_base <- model$ll[1]
+  .r2_nagelkerke(model, l_base)
+}
